@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
-
 from mootdx import config
-from mootdx.consts import EX_HOSTS, GP_HOSTS, HQ_HOSTS
+from mootdx.consts import EX_HOSTS
+from mootdx.consts import GP_HOSTS
+from mootdx.consts import HQ_HOSTS
 from mootdx.server import Server
 from mootdx.utils import get_config_path
 
-__version__ = '0.7.14'
+__version__ = '0.7.16'
 __author__ = "bopo.wang<ibopo@126.com>"
 
 config.setup()
