@@ -5,4 +5,4 @@ from loguru import logger
 log = logger
 log.remove()
 
-log.add(sys.stderr, level='INFO')
+log.add(sys.stderr, level="INFO")
